==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/ta/admin/users/general.php <==
<?php


return array(
    'activated_help_text' => 'This user can login',
    'activated_disabled_help_text' => 'You cannot edit activation status for your own account.',
    'assets_user'       => 'பெயரிடப்பட்ட சொத்துகள்: பெயர்',
    'bulk_update_warn'	=> 'User_count பயனர்களின் பண்புகளை நீங்கள் திருத்த வேண்டும். இந்த படிவத்தைப் பயன்படுத்தி உங்கள் சொந்த பயனர் பண்புகளை நீங்கள் மாற்ற முடியாது என்பதை நினைவில் கொள்ளவும், உங்கள் தனிப்பட்ட பயனருக்கு தனித்தனியாக திருத்தவும் வேண்டும்.',
    'bulk_update_help'	=> 'பல முறை பயனர்களைப் புதுப்பிக்க இந்த படிவம் உங்களை அனுமதிக்கிறது. நீங்கள் மாற்ற வேண்டிய துறைகள் மட்டுமே நிரப்பவும். காலியாக உள்ள எந்த புலமும் மாறாமல் இருக்கும்.',
    'current_assets'    => 'இந்த பயனருக்கு தற்போது சொத்துகள் சரிபார்க்கப்பட்டன',
    'clone'             => 'குளோன் பயனர்',
    'contact_user'      => 'தொடர்பு: பெயர்',
    'edit'              => 'பயனர் திருத்து',
    'filetype_info'     => 'அனுமதிக்கப்பட்ட கோப்புரிமைகள் png, gif, jpg, jpeg, doc, docx, pdf, txt, zip மற்றும் rar ஆகியவை.',
    'history_user'      => 'வரலாறு: பெயர்',
	'info'				=> 'தகவல்',
    'restore_user'		=> 'அவற்றை மீட்டெடுக்க இங்கு கிளிக் செய்க.',
    'last_login'        => 'கடைசி தேதி',
    'ldap_config_text'  => 'LDAP உள்ளமைவு அமைப்புகள் நிர்வாகம்> அமைப்புகள். இறக்குமதி செய்யப்பட்ட அனைத்து பயனர்களுக்கும் (விரும்பினால்) தேர்ந்தெடுக்கப்பட்ட இடம் அமைக்கப்படும்.',
    'print_assigned'    => 'Print All Assigned',
    'software_user'     => 'மென்பொருள் சரிபார்க்கப்பட்டது: பெயர்',
    'send_email_help'   => 'You must provide an email address for this user to send them credentials. Emailing credentials can only be done on user creation. Passwords are stored in a one-way hash and cannot be retrieved once saved.',
    'view_user'         => 'பயனர் காண்க: பெயர்',
    'usercsv'           => 'CSV கோப்பு',
    'two_factor_admin_optin_help' => 'உங்கள் தற்போதைய நிர்வாக அமைப்புகள் இரண்டு காரணி அங்கீகரிப்பின் தேர்ந்தெடுக்கப்பட்ட செயல்பாட்டை அனுமதிக்கின்றன.',
    'two_factor_enrolled' => '2FA சாதனம் பதிவுசெய்யப்பட்டது',
    'two_factor_active'   => '2FA செயலில்',
    );

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/ta/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'This user can login',
    'activated_disabled_help_text' => 'You cannot edit activation status for your own account.',
    'assets_user'       => 'பெயரிடப்பட்ட சொத்துகள்: பெயர்',
    'bulk_update_warn'	=> 'User_count பயனர்களின் பண்புகளை நீங்கள் திருத்த வேண்டும். இந்த படிவத்தைப் பயன்படுத்தி உங்கள் சொந்த பயனர் பண்புகளை நீங்கள் மாற்ற முடியாது என்பதை நினைவில் கொள்ளவும், உங்கள் தனிப்பட்ட பயனருக்கு தனித்தனியாக திருத்தவும் வேண்டும்.',
    'bulk_update_help'	=> 'பல முறை பயனர்களைப் புதுப்பிக்க இந்த படிவம் உங்களை அனுமதிக்கிறது. நீங்கள் மாற்ற வேண்டிய துறைகள் மட்டுமே நிரப்பவும். காலியாக உள்ள எந்த புலமும் மாறாமல் இருக்கும்.',
    'current_assets'    => 'இந்த பயனருக்கு தற்போது சொத்துகள் சரிபார்க்கப்பட்டன',
    'clone'             => 'குளோன் பயனர்',
    'contact_user'      => 'தொடர்பு: பெயர்',
    'edit'              => 'பயனர் திருத்து',
    'filetype_info'     => 'அனுமதிக்கப்பட்ட கோப்புரிமைகள் png, gif, jpg, jpeg, doc, docx, pdf, txt, zip மற்றும் rar ஆகியவை.',
    'history_user'      => 'வரலாறு: பெயர்',
    'info'				=> 'தகவல்',
    'restore_user'		=> 'அவற்றை மீட்டெடுக்க இங்கு கிளிக் செய்க.',
    'last_login'        => 'கடைசி தேதி',
    'ldap_config_text'  => 'LDAP உள்ளமைவு அமைப்புகள் நிர்வாகம்> அமைப்புகள். இறக்குமதி செய்யப்பட்ட அனைத்து பயனர்களுக்கும் (விரும்பினால்) தேர்ந்தெடுக்கப்பட்ட இடம் அமைக்கப்படும்.',
    'print_assigned'    => 'Print All Assigned',
    'software_user'     => 'மென்பொருள் சரிபார்க்கப்பட்டது: பெயர்',
    'send_email_help'   => 'You must provide an email address for this user to send them credentials. Emailing credentials can only be done on user creation. Passwords are stored in a one-way hash and cannot be retrieved once saved.',
    'view_user'         => 'பயனர் காண்க: பெயர்',
    'usercsv'           => 'CSV கோப்பு',
    'two_factor_admin_optin_help' => 'உங்கள் தற்போதைய நிர்வாக அமைப்புகள் இரண்டு காரணி அங்கீகரிப்பின் தேர்ந்தெடுக்கப்பட்ட செயல்பாட்டை அனுமதிக்கின்றன.',
    'two_factor_enrolled' => '2FA சாதனம் பதிவுசெய்யப்பட்டது',
    'two_factor_active'   => '2FA செயலில்',
    'user_deactivated'  => 'User is de-activated',
    'activation_status_warning' => 'Do not change activation status',
    'group_memberships_helpblock' => 'Only superadmins may edit group memberships.',
    'superadmin_permission_warning' => 'Only superadmins may grant a user superadmin access.',
    'admin_permission_warning' => 'Only users with admins rights or greater may grant a user admin access.',
    'remove_group_memberships' => 'Remove Group Memberships',
    'warning_deletion' => 'WARNING:',
    'warning_deletion_information' => 'You are about to delete the :count user(s) listed below. Super admin names are highlighted in red.',
    'update_user_asssets_status' => 'Update all assets for these users to this status',
    'checkin_user_properties' => 'Check in all properties associated with these users',
];
